[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
66/67: installer: "formating" → "formatting".
From: |
guix-commits |
Subject: |
66/67: installer: "formating" → "formatting". |
Date: |
Wed, 16 Jan 2019 19:00:45 -0500 (EST) |
civodul pushed a commit to branch wip-newt-installer
in repository guix.
commit c97c1fad5c528433b0acde6aaca42f8a7f8e8bfa
Author: Ludovic Courtès <address@hidden>
Date: Wed Jan 16 19:20:26 2019 +0100
installer: "formating" → "formatting".
* gnu/installer/newt/partition.scm,
gnu/installer/parted.scm: Replace "formating" with "formatting".
---
gnu/installer/newt/partition.scm | 18 +++++++++---------
gnu/installer/parted.scm | 26 +++++++++++++-------------
2 files changed, 22 insertions(+), 22 deletions(-)
diff --git a/gnu/installer/parted.scm b/gnu/installer/parted.scm
index 40054c0..187311e 100644
--- a/gnu/installer/parted.scm
+++ b/gnu/installer/parted.scm
@@ -55,7 +55,7 @@
user-partition-start
user-partition-end
user-partition-mount-point
- user-partition-need-formating?
+ user-partition-need-formatting?
user-partition-parted-object
find-esp-partition
@@ -154,7 +154,7 @@
(default #f))
(mount-point user-partition-mount-point ;string
(default #f))
- (need-formating? user-partition-need-formating? ; boolean
+ (need-formatting? user-partition-need-formatting? ; boolean
(default #f))
(parted-object user-partition-parted-object ; <partition> from parted
(default #f)))
@@ -541,7 +541,7 @@ determined by MAX-LENGTH-COLUMN procedure."
(fs-type-name (user-fs-type-name fs-type))
(bootable? (user-partition-bootable? user-partition))
(esp? (user-partition-esp? user-partition))
- (need-formating? (user-partition-need-formating? user-partition))
+ (need-formatting? (user-partition-need-formatting? user-partition))
(crypt-label (user-partition-crypt-label user-partition))
(size (user-partition-size user-partition))
(mount-point (user-partition-mount-point user-partition)))
@@ -585,9 +585,9 @@ determined by MAX-LENGTH-COLUMN procedure."
,@(if (or (freespace-partition? partition)
(eq? fs-type 'swap))
'()
- `((need-formating?
+ `((need-formatting?
. ,(string-append "Format the partition? : "
- (if need-formating? "Yes" "No")))))
+ (if need-formatting? "Yes" "No")))))
,@(if (or (eq? type 'extended)
(eq? fs-type 'swap))
'()
@@ -871,13 +871,13 @@ partition."
(error
(format #f "Unable to create partition ~a~%" name)))))))))
-(define (force-user-partitions-formating user-partitions)
+(define (force-user-partitions-formatting user-partitions)
"Set the NEED-FORMATING? fields to #t on all <user-partition> records of
USER-PARTITIONS list and return the updated list."
(map (lambda (p)
(user-partition
(inherit p)
- (need-formating? #t)))
+ (need-formatting? #t)))
user-partitions))
(define* (auto-partition disk
@@ -992,7 +992,7 @@ swap partition, a root partition and a home partition."
(crypt-label (and encrypted? "crypthome"))
(size "100%")
(mount-point "/home")))))))
- (new-partitions* (force-user-partitions-formating
+ (new-partitions* (force-user-partitions-formatting
new-partitions)))
(create-adjacent-partitions disk
new-partitions*
@@ -1091,8 +1091,8 @@ USER-PARTITION if it is encrypted, or the plain file-name
otherwise."
NEED-FORMATING? field set to #t."
(for-each
(lambda (user-partition)
- (let* ((need-formating?
- (user-partition-need-formating? user-partition))
+ (let* ((need-formatting?
+ (user-partition-need-formatting? user-partition))
(type (user-partition-type user-partition))
(crypt-label (user-partition-crypt-label user-partition))
(file-name (user-partition-upper-file-name user-partition))
@@ -1102,11 +1102,11 @@ NEED-FORMATING? field set to #t."
(case fs-type
((ext4)
- (and need-formating?
+ (and need-formatting?
(not (eq? type 'extended))
(create-ext4-file-system file-name)))
((fat32)
- (and need-formating?
+ (and need-formatting?
(not (eq? type 'extended))
(create-fat32-file-system file-name)))
((swap)
@@ -1293,7 +1293,7 @@ from (gnu system mapped-devices) and return it."
(define (free-parted devices)
"Deallocate memory used for DEVICES in parted, force sync them and wait for
the devices not to be used before returning."
- ;; XXX: Formating and further operations on disk partition table may fail
+ ;; XXX: Formatting and further operations on disk partition table may fail
;; because the partition table changes are not synced, or because the device
;; is still in use, even if parted should have finished editing
;; partitions. This is not well understood, but syncing devices and waiting
- 38/67: installer: locale: Set English as the default language., (continued)
- 38/67: installer: locale: Set English as the default language., guix-commits, 2019/01/16
- 34/67: installer: Remove group selection in user page., guix-commits, 2019/01/16
- 40/67: installer: keymap: Do not fail on non-kmscon terminals., guix-commits, 2019/01/16
- 45/67: installer: Make exit button optional for run-file-textbox-page., guix-commits, 2019/01/16
- 43/67: installer: partition: Differenciate Back button from Exit button., guix-commits, 2019/01/16
- 48/67: installer: menu: Fix typo., guix-commits, 2019/01/16
- 52/67: installer: Clear screen upon exit., guix-commits, 2019/01/16
- 44/67: installer: Make sure every sentence is dot terminated., guix-commits, 2019/01/16
- 47/67: installer: partition: Precise when using Manual/Guided partionment., guix-commits, 2019/01/16
- 65/67: installer: Adjust messages on the final page., guix-commits, 2019/01/16
- 66/67: installer: "formating" → "formatting".,
guix-commits <=
- 12/67: installer: Move everything to the build side., guix-commits, 2019/01/16
- 39/67: installer: Turn "Cancel" buttons into "Exit" buttons., guix-commits, 2019/01/16
- 23/67: installer: Do not ask for keyboard model., guix-commits, 2019/01/16
- 62/67: installer: partition: Add encryption password confirmation., guix-commits, 2019/01/16
- 60/67: installer: Remove debug popup., guix-commits, 2019/01/16
- 54/67: installer: parted: Use read-luks-partition-uuid instead of find-partition-by-luks-uuid., guix-commits, 2019/01/16
- 59/67: installer: welcome: Put "Graphical installer" ahead., guix-commits, 2019/01/16
- 55/67: installer: Various renamings., guix-commits, 2019/01/16
- 64/67: syscalls: 'device-in-use?' returns #f upon EINVAL., guix-commits, 2019/01/16
- 42/67: installer: network: Do not show an empty technology list., guix-commits, 2019/01/16
diff --git a/gnu/installer/newt/partition.scm b/gnu/installer/newt/partition.scm
index 1c3ce80..c22e1c0 100644
--- a/gnu/installer/newt/partition.scm
+++ b/gnu/installer/newt/partition.scm
@@ -52,10 +52,10 @@
#:button-callback-procedure button-exit-action)))
(car result)))
-(define (draw-formating-page)
+(define (draw-formatting-page)
"Draw a page to indicate partitions are being formated."
(draw-info-page
- (format #f (G_ "Partition formating is in progress, please wait."))
+ (format #f (G_ "Partition formatting is in progress, please wait."))
(G_ "Preparing partitions")))
(define (run-device-page devices)
@@ -288,13 +288,13 @@ by USER-PART, if it is applicable for the partition type."
(G_ "Encryption label")))))
(user-partition
(inherit target-user-partition)
- (need-formating? #t)
+ (need-formatting? #t)
(crypt-label new-label))))
- ((need-formating?)
+ ((need-formatting?)
(user-partition
(inherit target-user-partition)
- (need-formating?
- (not (user-partition-need-formating?
+ (need-formatting?
+ (not (user-partition-need-formatting?
target-user-partition)))))
((size)
(let* ((old-size (user-partition-size target-user-partition))
@@ -392,7 +392,7 @@ partition. Leave this field empty if you don't want to set
a mounting point.")
(and new-partition
(user-partition
(inherit new-user-partition)
- (need-formating? #t)
+ (need-formatting? #t)
(file-name (partition-get-path new-partition))
(disk-file-name (device-path device))
(parted-object new-partition))))
@@ -758,8 +758,8 @@ by pressing the Exit button.~%~%")))
(user-partitions (run-page non-install-devices))
(user-partitions-with-pass (prompt-luks-passwords
user-partitions))
- (form (draw-formating-page)))
- ;; Make sure the disks are not in use before proceeding to formating.
+ (form (draw-formatting-page)))
+ ;; Make sure the disks are not in use before proceeding to formatting.
(free-parted non-install-devices)
(format-user-partitions user-partitions-with-pass)
(destroy-form-and-pop form)